﻿using System;
using System.Reflection;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;
using Microsoft.Extensions.Hosting;

using GrapeCity.ActiveReports.Aspnetcore.Viewer;
using Microsoft.Extensions.Configuration;

namespace JSViewerCoreMVCApplication2
{
    public class Startup
    {
        public static string EmbeddedReportsPrefix = "JSViewerCoreMVCApplication2.Reports";
        private AzureReportsStorage _storage;
        public Startup(IConfiguration configuration)
        {
            _storage = new AzureReportsStorage(configuration["connectionString"], configuration["share"]);
        }
        // This method gets called by the runtime. Use this method to add services to the container.
        public void ConfigureServices(IServiceCollection services)
        {
            //var connString = this.Configuration["connectionString"];
            //Console.WriteLine("Connection string: {0}",connString);

            services
                .AddLogging(config =>
                {
                    // Disable the default logging configuration
                    config.ClearProviders();

                    // Enable logging for debug mode only
                    if (Environment.GetEnvironmentVariable("ASPNETCORE_ENVIRONMENT") == Environments.Development)
                    {
                        config.AddConsole();
                    }
                })
                .AddReporting()
                .AddMvc(option => option.EnableEndpointRouting = false);
        }

        // This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
        public void Configure(IApplicationBuilder app, IWebHostEnvironment env)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
            }

            app.UseReporting(settings =>
            {
                // settings.UseEmbeddedTemplates(EmbeddedReportsPrefix, Assembly.GetAssembly(GetType()));
                settings.UseCustomStore((reportName) =>
                {
                    return this._storage.GetReport(reportName);
                });
                settings.UseCompression = true;
            });

            app.UseMvc();
        }
    }
}
